GivemeHelp README

Overview
givemehelp is a Python tool that runs a specified Python program and provides detailed error messages from both OpenAI and Google's Gemini AI. It retrieves the necessary API keys, executes the program, and in case of an error, generates and displays error explanations from both AI services. Additionally, it calculates the similarity between the AI responses to provide validity and ensure that the results can be trusted.